AbiTypeValidationExtensions extension

Extensions for convenient type checking with clear error messages.

on

Methods

requireType<T extends AbiType>(String message) → T

Available on AbiType, provided by the AbiTypeValidationExtensions extension

Ensures this type is an instance of T, throwing with a custom message if not.