AccountTransactionsFactory class

Factory for creating account management transactions.

Low-level factory for building unsigned account transactions. For high-level API with automatic gas estimation and signing.

Properties

config AccountTransactionsConfig
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createTransactionForGuardingAccount({required Address sender, Nonce? nonce}) Transaction
Creates transaction for activating guardian protection.
createTransactionForSavingKeyValue({required Address sender, required Map<Uint8List, Uint8List> keyValuePairs, Nonce? nonce}) Transaction
Creates transaction for saving key-value pairs to account storage.
createTransactionForSettingGuardian({required Address sender, required Address guardianAddress, required String serviceId, Nonce? nonce}) Transaction
Creates transaction for setting guardian on account.
createTransactionForUnguardingAccount({required Address sender, Address? guardian, Nonce? nonce}) Transaction
Creates transaction for deactivating guardian protection.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited