ArgumentsCardinality class

Describes the argument count constraints for an endpoint.

Annotations
  • @immutable

Constructors

ArgumentsCardinality({required int min, required int max, required bool variadic})
Creates cardinality with min, max, and variadic flag.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
max int
Maximum arguments.
final
min int
Minimum arguments.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
variadic bool
Whether variadic.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited