CloseProposalOutcome class

Result of a closeProposal event. Carries the commit hash and the boolean pass/fail status of the proposal at closing time.

Constructors

CloseProposalOutcome({required String commitHash, required bool passed})
Creates close proposal outcome.
const

Properties

commitHash String
final
hashCode int
The hash code for this object.
no setterinherited
passed bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited