Fields class final

Collection of fields for structs and tuples.

Manages a collection of Field instances, providing access by name or index. Handles validation, conversion to/from maps and lists.

Example

final fields = Fields([
  Field(name: 'x', value: U32Value(10)),
  Field(name: 'y', value: U32Value(20)),
]);

print(fields.length); // 2
print(fields.getValue('x').nativeValue); // 10
print(fields.toMap()); // {x: 10, y: 20}
Inheritance
Annotations
  • @immutable

Constructors

Fields(List<Field> fields)
Creates a collection of fields.
Fields.fromList(List values, List<FieldDefinition> definitions)
Creates fields from a list of values and field definitions.
factory
Fields.fromMap(Map<String, dynamic> map, List<FieldDefinition> definitions)
Creates fields from a map of name->value pairs and field definitions.
factory

Properties

first Field
The first element.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
Whether this collection has no elements.
no setterinherited
isNotEmpty bool
Whether this collection has at least one element.
no setterinherited
iterator Iterator<Field>
A new Iterator that allows iterating the elements of this Iterable.
no setteroverride
last Field
The last element.
no setterinherited
length int
The number of elements in this Iterable.
no setterinherited
names List<String>
Returns all field names.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
single Field
Checks that this iterable has only one element, and returns that element.
no setterinherited
values List<TypedValue>
Returns all field values.
no setter

Methods

any(bool test(Field element)) bool
Checks whether any element of this iterable satisfies test.
inherited
cast<R>() Iterable<R>
A view of this iterable as an iterable of R instances.
inherited
contains(Object? element) bool
Whether the collection contains an element equal to element.
inherited
elementAt(int index) Field
Returns the indexth element.
inherited
every(bool test(Field element)) bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements(Field element)) Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
firstWhere(bool test(Field element), {Field orElse()?}) Field
The first element that satisfies the given predicate test.
inherited
fold<T>(T initialValue, T combine(T previousValue, Field element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<Field> other) Iterable<Field>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(Field element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
getByName(String name) Field
Returns the field with the given name.
getValue(String name) TypedValue
Returns the value of the field with the given name.
join([String separator = ""]) String
Converts each element to a String and concatenates the strings.
inherited
lastWhere(bool test(Field element), {Field orElse()?}) Field
The last element that satisfies the given predicate test.
inherited
map<T>(T toElement(Field e)) Iterable<T>
The current elements of this iterable modified by toElement.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reduce(Field combine(Field value, Field element)) Field
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
singleWhere(bool test(Field element), {Field orElse()?}) Field
The single element that satisfies test.
inherited
skip(int count) Iterable<Field>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(Field element)) Iterable<Field>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
take(int count) Iterable<Field>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(Field element)) Iterable<Field>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) List<Field>
Creates a List containing the elements of this Iterable.
inherited
toMap() Map<String, dynamic>
Converts fields to a map of name->native value.
toNativeList() List
Converts fields to a list of native values.
toSet() Set<Field>
Creates a Set containing the same elements as this iterable.
inherited
toString() String
Returns a string representation of (some of) the elements of this.
override
tryGetByName(String name) Field?
Tries to get the field with the given name.
validateAgainst(List<FieldDefinition> definitions) → void
Validates all fields against their definitions.
where(bool test(Field element)) Iterable<Field>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() Iterable<R>
Creates a new lazy Iterable with all elements that have type T.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](int index) Field
Returns field at the given index.