NftCreateResult class

Result of NFT creation.

Constructors

NftCreateResult({required String tokenIdentifier, required BigInt nonce, required BigInt initialQuantity})
Creates NFT create result.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
initialQuantity BigInt
final
nonce BigInt
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tokenIdentifier String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited