ProposeAddProposerInput class
Input for proposing a new proposer.
- Annotations
-
- @immutable
Constructors
- ProposeAddProposerInput({required Address multisigContract, required Address proposer})
-
Creates input for adding a proposer.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- multisigContract → Address
-
Multisig contract address.
final
- proposer → Address
-
New proposer address.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited