TypeFormulaLexer class
Lexical analyzer for type formula strings.
Constructors
- TypeFormulaLexer(String _input)
- Creates lexer for input string.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
nextToken(
) → Token - Gets next token from input.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
tokenize(
) → List< Token> - Tokenizes entire input string.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited