UnsetSpecialRoleInput class

Input for unsetting special role on non-fungible token.

Constructors

UnsetSpecialRoleInput({required Address user, required String tokenIdentifier, bool removeRoleNFTBurn = false, bool removeRoleNFTUpdateAttributes = false, bool removeRoleNFTAddURI = false, bool removeRoleESDTTransferRole = false, bool? removeRoleESDTModifyCreator, bool? removeRoleNFTRecreate, bool? removeRoleESDTSetNewURI, bool? removeRoleESDTModifyRoyalties})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
removeRoleESDTModifyCreator bool?
final
removeRoleESDTModifyRoyalties bool?
final
removeRoleESDTSetNewURI bool?
final
removeRoleESDTTransferRole bool
final
removeRoleNFTAddURI bool
final
removeRoleNFTBurn bool
final
removeRoleNFTRecreate bool?
final
removeRoleNFTUpdateAttributes bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tokenIdentifier String
final
user Address
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited