ArgumentsCardinality class
Describes the argument count constraints for an endpoint.
- Annotations
-
- @immutable
Constructors
- ArgumentsCardinality({required int min, required int max, required bool variadic})
-
Creates cardinality with min, max, and variadic flag.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited