DelegationOutcomeParser class
Parser for delegation transaction outcomes. Extracts structured results from delegation transactions by analyzing logs and events.
Constructors
- DelegationOutcomeParser()
-
Creates delegation outcome parser.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parseCreateNewDelegationContract(
TransactionOnNetwork transaction) → List< CreateDelegationContractResult> - Parses result of creating new delegation contract. Extracts contract address from SCDeploy events in transaction logs.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited