IssueNonFungibleInput class
Input for issuing non-fungible tokens.
- Inheritance
-
- Object
- IssueInput
- IssueNonFungibleInput
Constructors
Properties
- canAddSpecialRoles → bool
-
Can add special roles.
finalinherited
- canChangeOwner → bool
-
Can change owner.
finalinherited
- canFreeze → bool
-
Can freeze.
finalinherited
- canPause → bool
-
Can pause.
finalinherited
- canTransferNFTCreateRole → bool
-
final
- canUpgrade → bool
-
Can upgrade.
finalinherited
- canWipe → bool
-
Can wipe.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tokenName → String
-
Token name.
finalinherited
- tokenTicker → String
-
Token ticker.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited