MultiTransferItem class
A single leg of a MultiESDTNFTTransfer.
Constructors
- MultiTransferItem({required String tokenIdentifier, required int nonce, required BigInt amount})
-
const
Properties
- amount → BigInt
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFungible → bool
-
Whether this leg is a plain fungible transfer (nonce == 0).
no setter
- nonce → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tokenIdentifier → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited