NullLogger class
Null logger that silently discards all log messages.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
critical(
String message, {Object? error, StackTrace? stackTrace, Map< String, dynamic> ? context}) → void -
Logs critical error message.
inherited
-
debug(
String message, {Map< String, dynamic> ? context}) → void -
Logs debug message.
inherited
-
error(
String message, {Object? error, StackTrace? stackTrace, Map< String, dynamic> ? context}) → void -
Logs error message.
inherited
-
info(
String message, {Map< String, dynamic> ? context}) → void -
Logs info message.
inherited
-
log(
LogLevel level, String message, {Map< String, dynamic> ? context, Object? error, StackTrace? stackTrace}) → void -
Discards log message (no-op implementation).
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
warning(
String message, {Map< String, dynamic> ? context}) → void -
Logs warning message.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited