PemException class
Exception thrown when PEM parsing fails.
Example
try {
final key = parseUserKey(invalidPem);
} on PemException catch (e) {
print('PEM parsing failed: ${e.message}');
}
- Inheritance
-
- Object
- AbidockException
- WalletException
- PemException
Constructors
- PemException(String message, {Object? cause, StackTrace? stackTrace})
-
Creates a PEM parsing exception.
const
Properties
- cause → Object?
-
Underlying cause of the exception (if any).
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable error message.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
Stack trace when the exception was created.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited