UnexpectedEventCountException class
Exception for unexpected event count when expecting 0 or 1 events.
- Implemented types
Constructors
- UnexpectedEventCountException(String message, String identifier)
-
Creates exception with error message and event identifier.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier → String
-
Event identifier that caused the exception.
final
- message → String
-
Error message describing the issue.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited